pub struct DescriptorError { /* private fields */ }Expand description
An error that may occur while creating a DescriptorPool.
Implementations
Sourceimpl DescriptorError
impl DescriptorError
Sourcepub fn line(&self) -> Option<usize>
pub fn line(&self) -> Option<usize>
The 0-based line number at which this error occurred, if available.
This field may be None if the error is not associated with a particular source location, or the
source_code_info field was not populated for the input file.
Sourcepub fn column(&self) -> Option<usize>
pub fn column(&self) -> Option<usize>
The 0-based column number at which this error occurred, if available.
This field may be None if the error is not associated with a particular source location, or the
source_code_info field was not populated for the input file.
Sourcepub fn path(&self) -> Option<&[i32]>
pub fn path(&self) -> Option<&[i32]>
Gets the path where this error occurred in the FileDescriptorProto, if available.
See path for more details on the structure of the path.
Sourcepub fn with_source_code(self, source: &str) -> Self
Available on crate feature miette only.
pub fn with_source_code(self, source: &str) -> Self
miette only.Provide source code information for this error.
The source should correspond to the contents of file().